SystemOrganization addCategory: #'NetworkTests-Kernel'!
SystemOrganization addCategory: #'NetworkTests-Mail'!
SystemOrganization addCategory: #'NetworkTests-Protocols'!
SystemOrganization addCategory: #'NetworkTests-RFC822'!
SystemOrganization addCategory: #'NetworkTests-URI'!
SystemOrganization addCategory: #'NetworkTests-UUID'!
SystemOrganization addCategory: #'NetworkTests-Url'!

ClassTestCase subclass: #FileUrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!FileUrlTest methodsFor: 'testing' stamp: 'fbs 2/2/2005 12:43'!
testAsString
	| target url |
	target := 'file://localhost/etc/rc.conf'.
	url := target asUrl.
	self assert: url asString = target.
		! !

!FileUrlTest methodsFor: 'testing' stamp: 'SeanDeNigris 1/30/2011 12:03'!
testMatchingSchemesToSubclasses

	{ { nil. HttpUrl }. "Assume HTTP by default (i.e. when no scheme is provided)"
	{ 'isbn'. GenericUrl }. "Handle unknown Url types with GenericUrl"
	{ 'http'. HttpUrl }.
	{ 'ftp'. FtpUrl }.
	{ 'file'. FileUrl }.
	{ 'mailto'. MailtoUrl }.
	{ 'browser'. BrowserUrl } } do: [ :pair | | schemeString urlClassToUse |
		schemeString := pair first.
		urlClassToUse := pair second.
		self assert: ((Url urlClassForScheme: schemeString) = urlClassToUse) ].! !

ClassTestCase subclass: #GenericUrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!GenericUrlTest methodsFor: 'testing' stamp: 'fbs 2/2/2005 12:56'!
testAsString
	| url |
	url := GenericUrl new schemeName: 'sip' locator: 'foo@bar'.
	self assert: url asString = 'sip:foo@bar'.! !

ClassTestCase subclass: #HierarchicalUrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!HierarchicalUrlTest methodsFor: 'testing' stamp: 'fbs 2/2/2005 13:03'!
testAsString
	| url |
	url := HierarchicalUrl new
		schemeName: 'ftp'
		authority: 'localhost'
		path: #('path' 'to' 'file')
		query: 'aQuery'.
	self assert: url asString = 'ftp://localhost/path/to/file?aQuery'.! !

ClassTestCase subclass: #SocketStreamTest
	instanceVariableNames: 'clientStream serverStream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Kernel'!

!SocketStreamTest methodsFor: 'setup' stamp: 'ar 8/2/2010 18:10'!
setUp
	| listener clientSocket serverSocket |
	listener := Socket newTCP.
	[listener listenOn: 0 backlogSize: 4.

	clientSocket := Socket newTCP.
	clientSocket connectTo: #[127 0 0 1] port: listener localPort.
	clientSocket waitForConnectionFor: 1.
	self assert: clientSocket isConnected.

	serverSocket := listener waitForAcceptFor: 1.
	self assert: serverSocket isConnected.
	] ensure:[listener destroy].

	clientStream := SocketStream on: clientSocket.
	serverStream := SocketStream on: serverSocket.
! !

!SocketStreamTest methodsFor: 'setup' stamp: 'ar 8/2/2010 17:59'!
tearDown
	clientStream ifNotNil:[clientStream destroy].
	serverStream ifNotNil:[serverStream destroy].! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/5/2010 12:20'!
testNextIntoClose
	"Ensure that #next:into: will function properly when the connection is closed"

	clientStream nextPutAll:'A line of text'; flush.
	[(Delay forMilliseconds: 100) wait.
	clientStream close] fork.
	self assert: (serverStream next: 100 into: (String new: 100) startingAt: 1) 
		equals: 'A line of text'.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/5/2010 12:20'!
testNextIntoCloseNonSignaling
	"Ensure that #next:into: will function properly when the connection is closed"

	serverStream shouldSignal: false.
	clientStream nextPutAll:'A line of text'; flush.
	[(Delay forMilliseconds: 100) wait.
	clientStream close] fork.
	self assert: (serverStream next: 100 into: (String new: 100) startingAt: 1)
		equals: 'A line of text'.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:32'!
testUpTo
	"Tests correct behavior of #upTo:"

	clientStream nextPutAll:'A line of text', String cr, 'with more text'; flush.
	self assert: (serverStream upTo: Character cr) = 'A line of text'.
	[(Delay forSeconds: 1) wait.
	clientStream nextPutAll: String cr; flush] fork.
	self assert: (serverStream upTo: Character cr) = 'with more text'.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:32'!
testUpToAfterCloseNonSignaling
	"Tests correct behavior of #upToAll"

	| resp |
	clientStream nextPutAll: 'A line of text'.
	clientStream close.
	serverStream shouldSignal: false.
	self shouldnt: [resp := serverStream upTo: Character cr] raise: ConnectionClosed.
	self assert: resp = 'A line of text'.! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:32'!
testUpToAfterCloseSignaling
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll:'A line of text'.
	clientStream close.
	self should: [serverStream upTo: Character cr] raise: ConnectionClosed.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:29'!
testUpToAll
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll:'A line of text', String crlf, 'with more text'; flush.
	self assert: (serverStream upToAll: String crlf) = 'A line of text'.
	[(Delay forSeconds: 1) wait.
	clientStream nextPutAll: String crlf; flush] fork.
	self assert: (serverStream upToAll: String crlf) = 'with more text'.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:02'!
testUpToAllAfterCloseNonSignaling
	"Tests correct behavior of #upToAll"

	| resp |
	clientStream nextPutAll: 'A line of text'.
	clientStream close.
	serverStream shouldSignal: false.
	self shouldnt: [resp := serverStream upToAll: String crlf] raise: ConnectionClosed.
	self assert: resp = 'A line of text'.! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:26'!
testUpToAllAfterCloseSignaling
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll:'A line of text'.
	clientStream close.
	self should: [serverStream upToAll: String crlf] raise: ConnectionClosed.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:48'!
testUpToAllLimit
	"Tests correct behavior of #upToAll:limit:"

	clientStream nextPutAll:'A line of text'; flush.
	self assert: (serverStream upToAll: String crlf limit: 5) = 'A line of text'.! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:11'!
testUpToAllTimeout
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll: 'A line of text'.
	serverStream timeout: 1.
	self should: [serverStream upToAll: String crlf] raise: ConnectionTimedOut.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/5/2010 12:20'!
testUpToEndClose
	"Ensure that #upToEnd will function properly when the connection is closed"

	clientStream nextPutAll:'A line of text'; flush.
	[(Delay forMilliseconds: 100) wait.
	clientStream close] fork.
	self assert: (serverStream upToEnd) 
		equals: 'A line of text'.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/5/2010 12:20'!
testUpToEndCloseNonSignaling
	"Ensure that #upToEnd will function properly when the connection is closed"

	serverStream shouldSignal: false.
	clientStream nextPutAll:'A line of text'; flush.
	[(Delay forMilliseconds: 100) wait.
	clientStream close] fork.
	self assert: (serverStream upToEnd)
		equals: 'A line of text'.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:49'!
testUpToMax
	"Tests correct behavior of #upToAll:max:"

	clientStream nextPutAll:'A line of text'; flush.
	self assert: (serverStream upTo: Character cr limit: 5) = 'A line of text'.! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:32'!
testUpToTimeout
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll: 'A line of text'.
	serverStream timeout: 1.
	self should: [serverStream upTo: Character cr] raise: ConnectionTimedOut.
! !

ClassTestCase subclass: #UrlTest
	instanceVariableNames: 'url baseUrl'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!UrlTest commentStamp: '<historical>' prior: 0!
This is the unit test for the class Url. Unit tests are a good way to exercise the functionality of your system in a repeatable and automatic manner. They are therefore recommended if you plan to release anything. For more information, see: 
	- http://www.c2.com/cgi/wiki?UnitTest
	- there is a chapter in the PharoByExample book (http://pharobyexample.org)
	- the sunit class category!

!UrlTest methodsFor: 'tests' stamp: 'md 4/21/2003 13:58'!
testAbsoluteBrowser

	url := Url absoluteFromText: 'browser:bookmarks#mainPart'.

	self assert: url schemeName = 'browser'.
	self assert: url locator = 'bookmarks'.
	self assert:url fragment = 'mainPart'.
	self assert: url class = BrowserUrl.
	! !

!UrlTest methodsFor: 'tests' stamp: 'md 4/21/2003 13:29'!
testAbsoluteFILE
	
	url := Url absoluteFromText: 'file:/etc/passwd#foo'.

	self assert: url schemeName = 'file'.
	self assert: url path first = 'etc'.
	self assert: url path size = 2.	
	self assert: url fragment = 'foo'.! !

!UrlTest methodsFor: 'tests' stamp: 'md 4/21/2003 13:32'!
testAbsoluteFILE2
	
	url := 'fILE:/foo/bar//zookie/?fakequery/#fragger' asUrl.

	self assert: url schemeName = 'file'.
	self assert: url class = FileUrl.
	self assert: url path first ='foo'.
	self assert: url path size = 5.
	self assert: url fragment = 'fragger'.! !

!UrlTest methodsFor: 'tests' stamp: 'gk 2/12/2004 21:30'!
testAbsoluteFILE3
	"Just a few selected tests for FileUrl, not complete by any means."


	{'file:'. 'file:/'. 'file://'} do: [:s |
	 	url := FileUrl absoluteFromText: s.
		self assert: (url asString = 'file:///').
		self assert: (url host = '').
		self assert: url isAbsolute].
	
	url := FileUrl absoluteFromText: 'file://localhost/dir/file.txt'.
	self assert: (url asString = 'file://localhost/dir/file.txt').
	self assert: (url host = 'localhost').
	
	url := FileUrl absoluteFromText: 'file://localhost/dir/file.txt'.
	self assert: (url asString = 'file://localhost/dir/file.txt').
	self assert: (url host = 'localhost').
	self assert: url isAbsolute.
	
	url := FileUrl absoluteFromText: 'file:///dir/file.txt'.
	self assert: (url asString = 'file:///dir/file.txt').
	self assert: (url host = '').
	self assert: url isAbsolute.
	
	url := FileUrl absoluteFromText: '/dir/file.txt'.
	self assert: (url asString = 'file:///dir/file.txt').
	self assert: url isAbsolute.
	
	url := FileUrl absoluteFromText: 'dir/file.txt'.
	self assert: (url asString = 'file:///dir/file.txt').
	self deny: url isAbsolute.
	
	url := FileUrl absoluteFromText: 'c:/dir/file.txt'.
	self assert: (url asString = 'file:///c%3A/dir/file.txt').
	self assert: url isAbsolute.
	
	"Only a drive letter doesn't refer to a directory."
	url := FileUrl absoluteFromText: 'c:'.
	self assert: (url asString = 'file:///c%3A/').
	self assert: url isAbsolute.
	
	url := FileUrl absoluteFromText: 'c:/'.
	self assert: (url asString = 'file:///c%3A/').
	self assert: url isAbsolute! !

!UrlTest methodsFor: 'tests' stamp: 'md 4/21/2003 13:05'!
testAbsoluteFTP
	
	url := 'ftP://some.server/some/directory/' asUrl.

	self assert: url schemeName = 'ftp'.
	self assert: url class = FtpUrl.
	self assert: url authority = 'some.server'.	
	self assert: url path first = 'some'.
	self assert: url path size  = 3.
	! !

!UrlTest methodsFor: 'tests' stamp: 'md 4/21/2003 13:05'!
testAbsoluteHTTP
	
	url := 'hTTp://chaos.resnet.gatech.edu:8000/docs/java/index.html?A%20query%20#part' asUrl.

	self assert: url schemeName = 'http'.
	self assert: url authority = 'chaos.resnet.gatech.edu'.
	self assert: url path first = 'docs'.
	self assert: url path size = 3.
	self assert: url query = 'A%20query%20'.
	self assert: url fragment = 'part'.! !

!UrlTest methodsFor: 'tests' stamp: 'md 1/5/2004 14:51'!
testAbsolutePortErrorFix
	
	self shouldnt: [Url absoluteFromText: 'http://swikis.ddo.jp:8823/'] raise: Error.

	self should: [Url absoluteFromText: 'http://swikis.ddo.jp:-1/'] raise: Error.
	self should: [Url absoluteFromText: 'http://swikis.ddo.jp:65536/'] raise: Error.
	self should: [Url absoluteFromText: 'http://swikis.ddo.jp:auau/'] raise: Error.! !

!UrlTest methodsFor: 'tests' stamp: 'md 4/21/2003 13:08'!
testAbsoluteTELNET
	
	url := 'telNet:chaos.resnet.gatech.edu#goo' asUrl.

	self assert: url schemeName = 'telnet'.
	self assert: url locator = 'chaos.resnet.gatech.edu'.
	self assert: url fragment = 'goo'.	
! !

!UrlTest methodsFor: 'tests' stamp: 'st 9/27/2004 15:48'!
testCombineWithRelative
	#(#('http://www.rfc1149.net/' 'foo.html' 'http://www.rfc1149.net/foo.html') #('http://www.rfc1149.net/index.html' 'foo.html' 'http://www.rfc1149.net/foo.html') #('http://www.rfc1149.net/devel/' '../sam/' 'http://www.rfc1149.net/sam/') #('http://www.rfc1149.net/devel/index.html' '../sam/' 'http://www.rfc1149.net/sam/')) 
		do: [:a | self assert: (Url combine: a first withRelative: a second) = a third]! !

!UrlTest methodsFor: 'testing' stamp: 'bp 2/12/2005 20:21'!
testFromFileNameOrUrlString

	url := Url absoluteFromFileNameOrUrlString: 'asdf'.
	self assert: url schemeName = 'file'.
	self assert: url fragment isNil.
	self assert: url class = FileUrl.

	url := Url absoluteFromFileNameOrUrlString: 'http://209.143.91.36/super/SuperSwikiProj/AAEmptyTest.001.pr'.
	self assert: url schemeName = 'http'.
	self assert: url fragment isNil.
	self assert: url class = HttpUrl.! !

!UrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 13:21'!
testRelativeFILE
	
	| url2 |
	baseUrl := 'file:/some/dir#fragment1' asUrl.
	url := baseUrl newFromRelativeText: 'file:../another/dir/#fragment2'.
	self assert: url asText =  'file:///another/dir/#fragment2'.
	
	url := FileUrl absoluteFromText: 'file://localhost/dir/dir2/file.txt'.
	url2 := FileUrl absoluteFromText: 'file://hostname/flip/file.txt'.
	url2 privateInitializeFromText: '../file2.txt' relativeTo: url.
	self assert: (url2 asString = 'file://localhost/dir/file2.txt').
	self assert: (url2 host = 'localhost').
	self assert: url2 isAbsolute.
	
	url := FileUrl absoluteFromText: 'file://localhost/dir/dir2/file.txt'.
	url2 := FileUrl absoluteFromText: 'flip/file.txt'.
	self deny: url2 isAbsolute.
	url2 privateInitializeFromText: '.././flip/file.txt' relativeTo: url.
	self assert: (url2 asString = 'file://localhost/dir/flip/file.txt').
	self assert: (url2 host = 'localhost').
	self assert: url2 isAbsolute.
	
! !

!UrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 13:21'!
testRelativeFTP
	
	baseUrl := 'ftp://somewhere/some/dir/?query#fragment' asUrl.
	url := baseUrl newFromRelativeText: 'ftp://a.b'.

	self assert: url asString =  'ftp://a.b/'.! !

!UrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 13:21'!
testRelativeFTP2
	
	baseUrl := 'ftp://somewhere/some/dir/?query#fragment' asUrl.
	url := baseUrl newFromRelativeText: 'ftp:xyz'.


	self assert: url asString =  'ftp://somewhere/some/dir/xyz'.! !

!UrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 13:21'!
testRelativeFTP3
	
	baseUrl := 'ftp://somewhere/some/dir/?query#fragment' asUrl.
	url := baseUrl newFromRelativeText: 'http:xyz'.

	self assert: url asString = 'http://xyz/'.! !

!UrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 13:21'!
testRelativeHTTP
	
	baseUrl := 'http://some.where/some/dir?query1#fragment1' asUrl.
	url := baseUrl newFromRelativeText: '../another/dir/?query2#fragment2'.

	self assert: url asString =  'http://some.where/another/dir/?query2#fragment2'.! !

!UrlTest methodsFor: 'tests' stamp: 'gk 2/12/2004 21:31'!
testRoundTripFILE
	"File URLs should round-trip OK. This test should ultimately be
	tested on all platforms."

	| fileName |
	fileName := FileDirectory default fullNameFor: 'xxx.st'.
	url := FileDirectory urlForFileNamed: fileName.
	self assert: (url pathForFile = fileName) description: 'fileName didn''t round-trip'.! !

!UrlTest methodsFor: 'tests' stamp: 'GabrielOmarCotelli 5/25/2010 21:22'!
testUsernamePassword
	"basic case with a username+password specified"

	url := 'http://user:pword@someserver.blah:8000/root/index.html' asUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port = 8000 ].
	self should: [ url path first = 'root' ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].	"basic case for a relative url"
	baseUrl := 'http://anotherserver.blah:9999/somedir/someotherdir/stuff/' asUrl.
	url := 'http://user:pword@someserver.blah:8000/root/index.html' asUrlRelativeTo: baseUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port = 8000 ].
	self should: [ url path first = 'root' ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].	"a true relative test that should keep the username and password from the base URL"
	baseUrl := 'http://user:pword@someserver.blah:8000/root/index.html' asUrl.
	url := '/anotherdir/stuff/' asUrlRelativeTo: baseUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port = 8000 ].
	self should: [ url path first = 'anotherdir' ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].	"just a username specified"
	url := 'http://user@someserver.blah:8000/root/index.html' asUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port = 8000 ].
	self should: [ url path first = 'root' ].
	self should: [ url username = 'user' ].
	self should: [ url password isNil ].	"the port is not specified"
	url := 'http://user:pword@someserver.blah/root/index.html' asUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port isNil ].
	self should: [ url path first = 'root' ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].	"neither a path nor a port is specified"
	url := 'http://user:pword@someserver.blah' asUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port isNil ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].	"relative URL where the username+password should be forgotten"
	baseUrl := 'http://user:pword@someserver.blah' asUrl.
	url := 'http://anotherserver.blah' asUrlRelativeTo: baseUrl.
	self should: [ url username isNil ].
	self should: [ url password isNil ]! !

!UrlTest methodsFor: 'tests' stamp: 'StephaneDucasse 5/9/2010 20:37'!
testUsernamePasswordEncoded2
	"Sometimes, weird usernames or passwords are necessary in applications, and, thus, we might receive them in a Url. The @ and the : ar the kind of critical ones."

	#(      "('user' 'pword' 'host' port 'path')"
	('Stphane rst Pckler' 'leckerEis' 'cottbus.brandenburg' 80 'mein/Zuhause')
	('Jeannde.d''Arc' 'jaiunescret' 'orleans' 8080 'une/deux/trois')
	('HaXor@roxor:fnac' 'my~Pa$wert' 'cbase' 42 'do/not_try')
	) do: [:urlParts | |theUrl|
			theUrl := ('http://{1}:{2}@{3}:{4}/{5}' format: {
				(urlParts at: 1) encodeForHTTP. 
				(urlParts at: 2) encodeForHTTP.
				urlParts at: 3. urlParts at: 4. urlParts at: 5.
			}) asUrl.
		self assert: (theUrl schemeName = 'http').
		self assert: (theUrl username = (urlParts at: 1)).
		self assert: (theUrl password = (urlParts at: 2)).
		self assert: (theUrl authority = (urlParts at: 3)).
		self assert: (theUrl port = (urlParts at: 4)).
		self assert: theUrl path first = ((urlParts at: 5) copyUpTo: $/ )]! !

!UrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 13:22'!
testUsernamePasswordPrinting

	#(	'http://user:pword@someserver.blah:8000/root/index.html'
		'http://user@someserver.blah:8000/root/index.html' 
		'http://user:pword@someserver.blah/root/index.html'
	) do: [ :urlText |
		self should: [ urlText = urlText asUrl asString ] ].

! !

!UrlTest methodsFor: 'tests' stamp: 'StephaneDucasse 5/9/2010 20:28'!
testUsernamePasswordPrintingEncoded
	
	#('http://F%C3%BCrst%20P%C3%BCckler:leckerEis@cottbus.brandenburg:80/mein/Zuhause'
	'http://Jeannde.d%27Arc:jaiunes%C3%A9cret@orleans:8080/une/deux/trois'
	'http://HaXor%40roxor%3Afnac:my%7EPa%24%C2%A7wert@cbase:42/do/not_try') 
		do: [ :urlText |
			self should: [ urlText = urlText asUrl asString ] ].! !

TestCase subclass: #Base64MimeConverterTest
	instanceVariableNames: 'message'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Kernel'!

!Base64MimeConverterTest commentStamp: '<historical>' prior: 0!
This is the unit test for the class Base64MimeConverter. Unit tests are a good way to exercise the functionality of your system in a repeatable and automatic manner. They are therefore recommended if you plan to release anything. For more information, see: 
	- http://www.c2.com/cgi/wiki?UnitTest
	- there is a chapter in the PharoByExample book (http://pharobyexample.org/)
	- the sunit class category!

!Base64MimeConverterTest methodsFor: 'setup' stamp: 'StephaneDucasse 1/16/2010 12:53'!
setUp
	message := 'Hi There!!' readStream.! !

!Base64MimeConverterTest methodsFor: 'tests' stamp: 'StephaneDucasse 1/16/2010 12:45'!
testBase64Encoded
	"self run: #testBase64Encoded"
	
	| encoded |
	encoded := (Base64MimeConverter mimeEncode: message) contents.
	self assert: encoded = 'Hi There!!' base64Encoded.
	! !

!Base64MimeConverterTest methodsFor: 'tests' stamp: 'StephaneDucasse 1/16/2010 12:54'!
testMimeEncodeDecode
	"self run: #testMimeEncodeDecode"
	
	| encoded |
	encoded := Base64MimeConverter mimeEncode: message.
	self assert: (encoded contents = 'SGkgVGhlcmUh').
      self assert: ((Base64MimeConverter mimeDecodeToChars: encoded) contents = message contents).

	"Encoding should proceed from the current stream position."
	message reset.
	message skip: 2.
	encoded := Base64MimeConverter mimeEncode: message.
	self assert: (encoded contents = 'IFRoZXJlIQ==').! !

!Base64MimeConverterTest methodsFor: 'tests' stamp: 'StephaneDucasse 1/16/2010 12:54'!
testOnByteArray
	"self run: #testOnByteArray"
	
	self assert: ('Hi There!!' base64Encoded = 'Hi There!!' asByteArray base64Encoded)! !

TestCase subclass: #HTTPSocketTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Protocols'!

!HTTPSocketTest methodsFor: 'tests' stamp: 'StephaneDucasse 3/27/2010 22:24'!
expandUrl
	"self debug: #expandUrl"
	
	self assert: (HTTPSocket expandUrl: 'www.pharo-project.org' ip: #[127 0 0 1] port: 8080) = 'www.pharo-project.org'.
	self assert: (HTTPSocket expandUrl: '../beam' ip: #[127 0 0 1] port: 8080) = '127.0.0.1:8080/beam'.
	self assert: (HTTPSocket expandUrl: '/beam' ip: #[127 0 0 1] port: 8080) = '127.0.0.1:8080/beam'.! !

!HTTPSocketTest methodsFor: 'tests' stamp: 'StephaneDucasse 3/27/2010 22:36'!
testExpandUrl
	"self debug: #testExpandUrl"
	
	self assert: (HTTPSocket expandUrl: 'www.pharo-project.org' ip: #[127 0 0 1] port: 8080) = 'www.pharo-project.org'.
	self assert: (HTTPSocket expandUrl: '../beam' ip: #[127 0 0 1] port: 8080) = '127.0.0.1:8080/beam'.
	self assert: (HTTPSocket expandUrl: '/beam' ip: #[127 0 0 1] port: 8080) = '127.0.0.1:8080/beam'.! !

!HTTPSocketTest methodsFor: 'tests' stamp: 'StephaneDucasse 3/27/2010 22:51'!
testIpPortUrlPath
	"self debug: #testIpPortUrlPath"
	
	self assert: (HTTPSocket  ip: #[127 0 0 1] port: 8080 urlPath: '/beam') = '127.0.0.1:8080/beam'! !

TestCase subclass: #HttpUrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!HttpUrlTest methodsFor: 'testing' stamp: 'MarcusDenker 4/16/2011 18:58'!
testHttps
	self assert: 'https://encrypted.google.com' asUrl scheme = 'https'.! !

!HttpUrlTest methodsFor: 'testing' stamp: 'StephaneDucasse 9/1/2010 14:37'!
testNormalizeContents
	| url document |
	url := Url absoluteFromText: 'http://www.pharo-project.org/logo.jpg'.
	document := MIMEDocument
		contents: #(1 2 3 4)
		mimeType: MIMEDocument defaultContentType
		uri: url.
	url normalizeContents: document! !

TestCase subclass: #MailAddressParserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-RFC822'!

!MailAddressParserTest commentStamp: '<historical>' prior: 0!
This is the unit test for the class MailAddressParser. Unit tests are a good way to exercise the functionality of your system in a repeatable and automatic manner. They are therefore recommended if you plan to release anything. For more information, see: 
	- http://www.c2.com/cgi/wiki?UnitTest
	- there is a chapter in the PharoByExample book (http://pharobyexample.org)
	- the sunit class category!

!MailAddressParserTest methodsFor: 'tests' stamp: 'sd 6/5/2005 10:31'!
testAddressesIn

	| testString correctAnswer |

	testString := 'joe@lama.com, joe2@lama.com joe3@lama.com joe4 , Not an Address <joe5@address>, joe.(annoying (nested) comment)literal@[1.2.3.4], "an annoying" group : joe1@groupie, joe2@groupie, "Joey" joe3@groupy, "joe6"."joe8"@group.com;,  Lex''s email account <lex>'.

correctAnswer := #('joe@lama.com' 'joe2@lama.com' 'joe3@lama.com' 'joe4' 'joe5@address' 'joe.literal@[1.2.3.4]' 'joe1@groupie' 'joe2@groupie' '"Joey"' 'joe3@groupy' '"joe6"."joe8"@group.com' 'lex') asOrderedCollection.

	self assert: ((MailAddressParser addressesIn: testString) =  correctAnswer).! !

TestCase subclass: #MailMessageTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Mail'!

!MailMessageTest methodsFor: 'tests' stamp: 'SeanDeNigris 12/6/2011 14:36'!
testCreateFromString

	| text message |
	text := 
'Date: Tue, 20 Feb 2001 13:52:53 +0300
From: mdr@scn.rg (Me Ru)
Subject: RE: Windows 2000 on your laptop
To: "Greg Y" <to1@mail.com>
cc: cc1@scn.org, cc1also@test.org
To: to2@no.scn.org, to2also@op.org
cc: cc2@scn.org

Hmmm... Good.  I will try to swap my German copy for something in
English, and then do the deed.  Oh, and expand my RAM to 128 first.

Mike
'.

	message := MailMessage from: text.

	self assert: message text = text.
	self assert: message subject = 'RE: Windows 2000 on your laptop'.
	self assert: message from = 'mdr@scn.rg (Me Ru)'.
	self assert: message date = '2/20/01'.
	self assert: message time = 667133573.
	self assert: message to = '"Greg Y" <to1@mail.com>, to2@no.scn.org, to2also@op.org'.
	self assert: message cc = 'cc1@scn.org, cc1also@test.org, cc2@scn.org'.! !

!MailMessageTest methodsFor: 'tests' stamp: 'TonyFleig 11/28/2010 13:12'!
testMultiPartAlternative
	| m txt html  part1 part2 |
	
	txt := 'This is plain text.'.
	html :=  '<html><head></head><body>This is html.</body></html>'.
	
	m := MailMessage empty.
	m addAlternativePart: txt contentType: 'text/plain'. 
	m addAlternativePart: html contentType: 'text/html'.

	self assert: (((m fields at: 'content-type') at: 1) mainValue asLowercase = 'multipart/alternative'). 
	self assert: (m parts size = 2).

	part1 := m parts at: 1.
	part2 := m parts at: 2.

	self assert: (((part1 fields at: 'content-type') at: 1) mainValue asLowercase = 'text/plain').
	self assert: ((part1 body content) = txt).
	
	self assert: (((part2 fields at: 'content-type') at: 1) mainValue asLowercase = 'text/html').
	self assert: ((part2 body content) = html).
! !

!MailMessageTest methodsFor: 'tests' stamp: 'TonyFleig 11/28/2010 13:48'!
testMultiPartMixed
	| m txt html  part1 part2 |
	
	txt := 'This is plain text.'.
	html :=  '<html><head></head><body>This is html.</body></html>'.
	
	m := MailMessage empty.
	m addMixedPart: txt contentType: 'text/plain'. 
	m addMixedPart: html contentType: 'text/html'.

	self assert: (((m fields at: 'content-type') at: 1) mainValue asLowercase = 'multipart/mixed'). 
	self assert: (m parts size = 2).

	part1 := m parts at: 1.
	part2 := m parts at: 2.

	self assert: (((part1 fields at: 'content-type') at: 1) mainValue asLowercase = 'text/plain').
	self assert: ((part1 body content) = txt).
	
	self assert: (((part2 fields at: 'content-type') at: 1) mainValue asLowercase = 'text/html').
	self assert: ((part2 body content) = html).
! !

!MailMessageTest methodsFor: 'tests' stamp: 'SeanDeNigris 12/2/2011 13:31'!
testRecipientList

	| message |
	message := MailMessage from: 'To: pharo-project@lists.gforge.inria.fr, pharo-users@lists.gforge.inria.fr'.
	
	self assert: (message recipientList size = 2).
	self assert: (message recipientList first = 'pharo-project@lists.gforge.inria.fr').	
	self assert: (message recipientList second = 'pharo-users@lists.gforge.inria.fr').! !

!MailMessageTest methodsFor: 'tests' stamp: 'SeanDeNigris 12/6/2011 16:26'!
testSimpleCreate

	| message |
	message := MailMessage
		from: 'community@world.st'
		to: { 'pharo-project@lists.gforge.inria.fr'. 'pharo-users@lists.gforge.inria.fr' }
		about: 'Great Progress'
		asFollows: 'Pharo is getting so cool!!'.
	
	self assert: (message text matchesRegex: 'Date\: [[:alpha:]]+, \d+ [[:alpha:]]+ \d+ \d\d\:\d\d\:\d\d [-+]\d\d\d\d
From\: community@world.st
Subject\: Great Progress
To\: pharo-project@lists.gforge.inria.fr, pharo-users@lists.gforge.inria.fr

Pharo is getting so cool!!
').! !

TestCase subclass: #NetNameResolverTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Kernel'!

!NetNameResolverTest methodsFor: 'testing' stamp: 'NouryBouraqadi 10/1/2010 16:27'!
localHostAddressIsLoopBackAddress
		^NetNameResolver localHostAddress = NetNameResolver loopBackAddress! !

!NetNameResolverTest methodsFor: 'testing' stamp: 'NouryBouraqadi 10/1/2010 16:29'!
localHostNameIsLoopBackName
		^NetNameResolver localHostName = NetNameResolver loopBackName! !

!NetNameResolverTest methodsFor: 'testing' stamp: 'NouryBouraqadi 10/1/2010 16:41'!
testLocalHostAddress
	NetNameResolver isConnected
		ifTrue: [self deny: self localHostAddressIsLoopBackAddress]
		ifFalse: [self assert: self localHostAddressIsLoopBackAddress]! !

!NetNameResolverTest methodsFor: 'testing' stamp: 'NouryBouraqadi 10/1/2010 16:45'!
testLocalHostName
	self deny: NetNameResolver localHostName isNil.
	NetNameResolver isConnected
		ifTrue: [self deny: self localHostNameIsLoopBackName]
		ifFalse: [self assert: self localHostNameIsLoopBackName]! !

TestCase subclass: #SMTPClientTest
	instanceVariableNames: 'smtp socket'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Protocols'!

!SMTPClientTest methodsFor: 'running' stamp: 'fbs 3/22/2004 13:11'!
setUp
	socket := MockSocketStream on: ''.
	smtp := SMTPClient new.
	smtp stream: socket.! !

!SMTPClientTest methodsFor: 'testing' stamp: 'fbs 3/23/2004 17:15'!
testMailFrom
	smtp mailFrom: 'frank@angband.za.org'.
	self assert: socket outStream contents = ('MAIL FROM: <frank@angband.za.org>', String crlf).
	
	socket resetOutStream.
	smtp mailFrom: '<frank@angband.za.org>'.
	self assert: socket outStream contents = ('MAIL FROM: <frank@angband.za.org>', String crlf).
	
	socket resetOutStream.
	smtp mailFrom: 'Frank <frank@angband.za.org>'.
	self assert: socket outStream contents = ('MAIL FROM: <frank@angband.za.org>', String crlf).! !

TestCase subclass: #SocketTest
	instanceVariableNames: 'listenerSocket clientSocket serverSocket'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Kernel'!

!SocketTest methodsFor: 'setup' stamp: 'SvenVanCaekenberghe 4/15/2011 12:10'!
listenerAddress
	^NetNameResolver loopBackAddress
! !

!SocketTest methodsFor: 'setup' stamp: 'ar 11/26/2010 10:13'!
listenerPort
	^42324
! !

!SocketTest methodsFor: 'setup' stamp: 'ar 11/26/2010 10:24'!
setUp

	listenerSocket := Socket newTCP listenOn: self listenerPort backlogSize: 4 interface: self listenerAddress.
! !

!SocketTest methodsFor: 'setup' stamp: 'ar 11/26/2010 10:24'!
tearDown

	listenerSocket ifNotNil:[listenerSocket destroy].
	clientSocket ifNotNil:[clientSocket destroy].
	serverSocket ifNotNil:[serverSocket destroy].
! !

!SocketTest methodsFor: 'tests' stamp: 'ar 11/26/2010 10:17'!
testClientConnect
	"Tests a client socket connection"

	clientSocket := Socket newTCP.
	clientSocket connectTo: self listenerAddress port: self listenerPort.
	clientSocket waitForConnectionFor: 2.
	self assert: clientSocket isConnected.
! !

!SocketTest methodsFor: 'tests' stamp: 'ar 11/26/2010 11:08'!
testDataReceive
	"Test data transfer and related methods"

	self testDataSending.
	"It can take a tad for the status change to be visible"
	(Delay forMilliseconds: 200) wait.
	self assert: serverSocket dataAvailable.
	self assert: (serverSocket receiveData = 'Hello World').
	self deny: (serverSocket dataAvailable).
! !

!SocketTest methodsFor: 'tests' stamp: 'ar 11/26/2010 11:06'!
testDataSending
	"Test data transfer and related methods"

	self testServerAccept.
	clientSocket sendData: 'Hello World'.
	clientSocket waitForSendDoneFor: 2.
	self assert: clientSocket sendDone.

! !

!SocketTest methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/15/2011 12:19'!
testLocalAddress
	"Tests the various localAddress values for sockets"

	self testServerAccept.
	self assert: listenerSocket localAddress asSocketAddress = self listenerAddress.
	self assert: clientSocket localAddress asSocketAddress = self listenerAddress.
	self assert: serverSocket localAddress asSocketAddress = self listenerAddress.
! !

!SocketTest methodsFor: 'tests' stamp: 'ar 11/26/2010 10:25'!
testLocalPort
	"Tests the various localPort values for sockets"

	self testServerAccept.
	self assert: listenerSocket localPort = self listenerPort.
	self assert: clientSocket localPort > 0.
	self assert: serverSocket localPort > 0.
! !

!SocketTest methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/15/2011 12:21'!
testRemoteAddress
	"Tests the various remoteAddress values for sockets"

	self testServerAccept.
	self assert: listenerSocket remoteAddress = #[0 0 0 0].
	self assert: clientSocket remoteAddress asSocketAddress = self listenerAddress.
	self assert: serverSocket remoteAddress asSocketAddress = self listenerAddress.
! !

!SocketTest methodsFor: 'tests' stamp: 'ar 11/26/2010 10:25'!
testRemotePort
	"Tests the various remoteAddress values for sockets"

	self testServerAccept.
	self assert: listenerSocket remotePort = 0.
	self assert: clientSocket remotePort = self listenerPort.
	self assert: serverSocket remotePort > 0.
! !

!SocketTest methodsFor: 'tests' stamp: 'ar 11/26/2010 10:25'!
testServerAccept
	"Tests a server-side accept"

	self testClientConnect.
	serverSocket := listenerSocket waitForAcceptFor: 2.
	self assert: (serverSocket notNil).
	self assert: (serverSocket isConnected).
! !

TestCase subclass: #TestURI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-URI'!

!TestURI commentStamp: 'mir 2/27/2002 14:42' prior: 0!
Main comment stating the purpose of this class and relevant relationship to other classes.


   Some parsers allow the scheme name to be present in a relative URI if
   it is the same as the base URI scheme.  This is considered to be a
   loophole in prior specifications of partial URI [RFC1630]. Its use
   should be avoided.

      http:g        =  http:g           ; for validating parsers
                    |  http://a/b/c/g   ; for backwards compatibility
!

!TestURI class methodsFor: 'test generation' stamp: 'sd 3/20/2008 22:28'!
generateAbnormalResolverTests
	"TestURI generateAbnormalResolverTests"

	| relURIString result method testPairs pair |

	testPairs := #(
		#('../../../g' 'http://a/../g' )
		#('../../../../g' 'http://a/../../g' )
		#('/./g' 'http://a/./g' )
		#('/../g' 'http://a/../g' )
		#('g.' 'http://a/b/c/g.' )
		#('.g' 'http://a/b/c/.g' )
		#('g..' 'http://a/b/c/g..' )
		#('..g' 'http://a/b/c/..g' )
		#('./../g' 'http://a/b/g' )
		#('./g/.' 'http://a/b/c/g/' )
		#('g/./h' 'http://a/b/c/g/h' )
		#('g/../h' 'http://a/b/c/h' )
		#('g;x=1/./y' 'http://a/b/c/g;x=1/y' )
		#('g;x=1/../y' 'http://a/b/c/y' )
		#('g?y/./x' 'http://a/b/c/g?y/./x' )
		#('g?y/../x' 'http://a/b/c/g?y/../x' )
		#('g#s/./x' 'http://a/b/c/g#s/./x' )
		#('g#s/../x' 'http://a/b/c/g#s/../x' )
	).
	1 to: testPairs size do: [:index |
		pair := testPairs at: index.
		relURIString := pair first.
		result := pair last.
		method := String streamContents: [:stream |
			stream nextPutAll: 'testResolveAbnormal' , index printString; cr.
			stream
				nextPutAll: '	| baseURI relURI resolvedURI |' ; cr;
				nextPutAll: '	baseURI := ''http://a/b/c/d;p?q'' asURI.' ; cr;
				nextPutAll: '	relURI := '; nextPut: $'; nextPutAll: relURIString; nextPutAll: '''.' ; cr;
				nextPutAll: '	resolvedURI := baseURI resolveRelativeURI: relURI.' ; cr;
				nextPutAll: '	self should: [resolvedURI asString = '''; nextPutAll: result; nextPutAll: '''].' ; cr].
		self compile: method classified: 'running resolving'].
! !

!TestURI class methodsFor: 'test generation' stamp: 'sd 3/20/2008 22:28'!
generateNormalResolverTests
	"TestURI generateNormalResolverTests"

	| relURIString result method testPairs pair |

	testPairs := #(
		#('g:h' 'g:h' )
		#('g' 'http://a/b/c/g' )
		#('./g' 'http://a/b/c/g' )
		#('g/' 'http://a/b/c/g/' )
		#('/g' 'http://a/g' )
		#('//g' 'http://g' )
		#('?y' 'http://a/b/c/?y' )
		#('g?y' 'http://a/b/c/g?y' )
		#('g#s' 'http://a/b/c/g#s' )
		#('g?y#s' 'http://a/b/c/g?y#s' )
		#(';x' 'http://a/b/c/;x' )
		#('g;x' 'http://a/b/c/g;x' )
		#('g;x?y#s' 'http://a/b/c/g;x?y#s' )
		#('.' 'http://a/b/c/' )
		#('./' 'http://a/b/c/' )
		#('..' 'http://a/b/' )
		#('../' 'http://a/b/' )
		#('../g' 'http://a/b/g' )
		#('../..' 'http://a/' )
		#('../../' 'http://a/' )
		#('../../g' 'http://a/g' )
	).
	1 to: testPairs size do: [:index |
		pair := testPairs at: index.
		relURIString := pair first.
		result := pair last.
		method := String streamContents: [:stream |
			stream nextPutAll: 'testResolveNormal' , index printString; cr.
			stream
				nextPutAll: '	| baseURI relURI resolvedURI |' ; cr;
				nextPutAll: '	baseURI := ''http://a/b/c/d;p?q'' asURI.' ; cr;
				nextPutAll: '	relURI := '; nextPut: $'; nextPutAll: relURIString; nextPutAll: '''.' ; cr;
				nextPutAll: '	resolvedURI := baseURI resolveRelativeURI: relURI.' ; cr;
				nextPutAll: '	self should: [resolvedURI asString = '''; nextPutAll: result; nextPutAll: '''].' ; cr].
		self compile: method classified: 'running resolving'].
! !

!TestURI methodsFor: 'tests 2396' stamp: 'StephaneDucasse 4/4/2010 21:22'!
test2396ParseFTP
	"From section 1.3."

	| uri uriString |
	uriString := 'ftp://ftp.is.co.za/rfc/rfc1808.txt'.
	uri := URI fromString: uriString.
	self assert:  (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque)! !

!TestURI methodsFor: 'tests 2396' stamp: 'StephaneDucasse 4/4/2010 21:26'!
test2396ParseGopher
	"From section 1.3."

	| uri uriString |
	uriString := 'gopher://spinaltap.micro.umn.edu/00/Weather/California/Los%20Angeles'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque)
	"we probably have a problem with the %20 escape character"! !

!TestURI methodsFor: 'tests 2396' stamp: 'StephaneDucasse 4/4/2010 21:27'!
test2396ParseHTTP1
	"From section 1.3."

	| uri uriString |
	uriString := 'http://www.math.uio.no/faq/compression-faq/part1.html'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque)! !

!TestURI methodsFor: 'tests 2396' stamp: 'StephaneDucasse 4/4/2010 21:30'!
test2396ParseHTTP2
	"From appendix B."

	| uri uriString |
	uriString := 'http://www.ics.uci.edu/pub/ietf/uri/#Related'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri fragment = 'Related')! !

!TestURI methodsFor: 'tests 2396' stamp: 'StephaneDucasse 4/4/2010 21:31'!
test2396ParseMailto
	"From section 1.3."

	| uri uriString |
	uriString := 'mailto:mduerst@ifi.unizh.ch'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self assert: (uri isOpaque)! !

!TestURI methodsFor: 'tests 2396' stamp: 'StephaneDucasse 4/4/2010 21:32'!
test2396ParseNew
	"From section 1.3."

	| uri uriString |
	uriString := 'news:comp.infosystems.www.servers.unix'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self assert: (uri isOpaque)! !

!TestURI methodsFor: 'tests 2396' stamp: 'StephaneDucasse 4/4/2010 21:33'!
test2396ParseTelnet
	"From section 1.3."

	| uri uriString |
	uriString := 'telnet://melvyl.ucop.edu/'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque)! !

!TestURI methodsFor: 'tests authority' stamp: 'StephaneDucasse 4/2/2010 22:04'!
testAbsoluteAuthority
	"self debug: #testAbsoluteAuthority"
	
	| uri absoluteURIString |
	"An absolute URI with authority. An absolute URI starts with a scheme:"
	absoluteURIString := 'http://www.pharo-project.org'. 
	uri := URI fromString: absoluteURIString.
	self assert: (uri asString = absoluteURIString).
	self assert: (uri isAbsolute).
	self assert: (uri authority asString = 'www.pharo-project.org').
	self deny: (uri isOpaque).! !

!TestURI methodsFor: 'parsing tests' stamp: 'StephaneDucasse 4/3/2010 12:15'!
testAbsoluteMailToScheme
	"self debug: #testAbsoluteMailToScheme"
	| uri |
	"[scheme:][//authority][path][?query][#fragment]
	where authority can be [user-info@]host[:port]"
	
	uri := URI fromString: 'mailto:somebody@somewhere.nowhere'.
	self assert: (uri scheme = 'mailto').
	self assert: (uri  schemeSpecificPart = 'somebody@somewhere.nowhere').
	self assert: (uri isAbsolute).
	self assert: (uri isOpaque).
	self deny: (uri isRelative)! !

!TestURI methodsFor: 'parsing tests' stamp: 'StephaneDucasse 4/3/2010 12:08'!
testAbsoluteURIHavingEmptyAuthority

	self shouldnt: [URI fromString: 'http://'] raise: IllegalURIException! !

!TestURI methodsFor: 'parsing tests' stamp: 'StephaneDucasse 4/3/2010 12:01'!
testAbsoluteURIOnlyHavingSchemeFail

	self should: [URI fromString: 'http:'] raise: IllegalURIException! !

!TestURI methodsFor: 'tests authority' stamp: 'StephaneDucasse 4/3/2010 13:14'!
testAbsoluteURIWithSimpleAuthority
	"self debug: #testAbsoluteURIWithSimpleAuthority"
	
	| uri uriString | 
	uriString := 'http://www.pharo-project.org'.			"An absolute URI with empty (but defined) authority."
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self assert: (uri authority asString = 'www.pharo-project.org').
	self assert: (uri scheme = 'http').
	self assert: (uri schemeIsHttp).
	self deny: (uri isOpaque).
	! !

!TestURI methodsFor: 'tests authority' stamp: 'StephaneDucasse 4/3/2010 12:06'!
testAbsolutionButEmptyURIAuthority
	"self debug: #testAbsolutionButEmptyURIAuthority"
	
	| uri uriString | 
	uriString := 'scheme://'.			"An absolute URI with empty (but defined) authority."
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri authority isNil).
	self deny: (uri isOpaque).
	! !

!TestURI methodsFor: 'expected failures' stamp: 'MarcusDenker 8/20/2011 13:55'!
testColonOnly
	"If there's a colon, there's a scheme.  Supposed to be, anyway."

	<expectedFailure>

	self should: [URI fromString: '://host/']
		raise: IllegalURIException! !

!TestURI methodsFor: 'running file' stamp: 'StephaneDucasse 4/2/2010 22:13'!
testDefaultDirRoundtrip
	"self debug:#testDefaultDirRoundtrip"
	
	| defaultDir defaultDirURI uriDir |
	defaultDir := FileDirectory default.
	defaultDirURI := defaultDir uri.
	uriDir := FileDirectory uri: defaultDirURI.
	self assert: (defaultDir fullName = uriDir fullName)! !

!TestURI methodsFor: 'tests query' stamp: 'StephaneDucasse 4/27/2010 10:14'!
testDirWithHash
	"Tests proper escaping of directories with hash mark"
	"self debug: #testDirWithHash"
	| uriDir origPath origDir dirURI |
	origPath := FileDirectory default pathName, '#123'.
	origDir := FileDirectory on: origPath.
	self assert: origDir pathName = origPath.
	dirURI := origDir uri.
	uriDir := FileDirectory uri: dirURI.
	self assert: origDir fullName = uriDir fullName! !

!TestURI methodsFor: 'running file' stamp: 'StephaneDucasse 4/2/2010 22:13'!
testDirectoryRoot

	| rootDir uriRoot uriDir |
	rootDir := FileDirectory root.
	uriRoot := 'file:///' asURI.
	self assert: uriRoot isAbsolute.
	uriDir := FileDirectory uri: uriRoot.
	self assert: (rootDir fullName = uriDir fullName)! !

!TestURI methodsFor: 'test path' stamp: 'MarcusDenker 8/20/2011 13:56'!
testDotDotInPath

	<expectedFailure>
	
	| uri uriString |
	uriString := '/../../path/to/resource'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self deny: (uri isAbsolute).
	self assert: (uri path size = 6).
	"do we cut in chunk the path"! !

!TestURI methodsFor: 'tests query' stamp: 'MarcusDenker 8/20/2011 13:55'!
testEmptyButDefinedQuery
	"Empty (but defined) query."

	<expectedFailure>

	| uri uriString |
	uriString := 'scheme:/path/to/resource?'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri query = '').! !

!TestURI methodsFor: 'tests ports' stamp: 'StephaneDucasse 4/3/2010 17:48'!
testHostWithPort

	| uri uriString |
	"[scheme:][//authority][path][?query][#fragment]
	where authority can be [user-info@]host[:port]"
	
	uriString := 'http://host:123/'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri authority port = 123).
! !

!TestURI methodsFor: 'expected failures' stamp: 'MarcusDenker 8/20/2011 13:55'!
testNoEscapedCharactersInScheme
	"No escaped characters in the scheme."

	<expectedFailure>

	self should: [URI fromString: 'sch%65me://host/']
		raise: IllegalURIException
! !

!TestURI methodsFor: 'tests user info' stamp: 'StephaneDucasse 4/3/2010 23:46'!
testNoPathOnlyAuthority


	| uri uriString |
	uriString := 'scheme://host'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self assert: (uri path = '').! !

!TestURI methodsFor: 'expected failures' stamp: 'MarcusDenker 8/20/2011 13:55'!
testNoPlusAtTheBeginningOfScheme
	"Digits and + and - and . may be allowed, but not at the beginning."

	<expectedFailure>

	self should: [URI fromString: '+scheme://host/']
		raise: IllegalURIException.
	self should: [URI fromString: '-scheme://host/']
		raise: IllegalURIException.
	self should: [URI fromString: '.scheme://host/']
		raise: IllegalURIException.
	self shouldnt: [URI fromString: 'sche-me://host/']
		raise: IllegalURIException.
	self shouldnt: [URI fromString: 'sche+me://host/']
		raise: IllegalURIException.
	self shouldnt: [URI fromString: 'sche.me://host/']
		raise: IllegalURIException
! !

!TestURI methodsFor: 'tests ports' stamp: 'MarcusDenker 8/20/2011 13:56'!
testNonNumericPorts
	"Ports are numeric; non-numeric ports become part of a regName."
	"We should check the spec and see what should be done"
	
	<expectedFailure>
	
	| uri uriString |
	uriString := 'scheme://host:port/'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri authority name = 'host:port')
! !

!TestURI methodsFor: 'tests user info' stamp: 'StephaneDucasse 4/4/2010 00:29'!
testOpaque

	| uri uriString |
	uriString := 'scheme:opaque'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self assert: (uri isOpaque).
	self assert: (uri schemeSpecificPart = 'opaque').! !

!TestURI methodsFor: 'tests query' stamp: 'StephaneDucasse 4/3/2010 13:13'!
testOpaqueQuery
	"An opaque URI cannot have a query, because the opaque part may includes any $?."

	| uri uriString |
	"An opaque URI is an absolute URI whose scheme-specific part does not begin with a slash character ('/')"
	"[scheme:]scheme-specific-part[#fragment]"
	
	uriString := 'scheme:opaque?query'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self assert: (uri isOpaque).
	self should: [ uri query] raise: Error.
! !

!TestURI methodsFor: 'tests user info' stamp: 'StephaneDucasse 4/2/2010 22:44'!
testParseBadCharacterInUserInfo
	"self debug: #testParseBadCharacterInUserInfo"

	| uri uriString |
	uriString := 'scheme://$%%&**()!!.@host/'.
	uri := URI fromString: uriString.
	self assert: (uri authority userInfo = '$%%&**()!!.')! !

!TestURI methodsFor: 'fragment' stamp: 'StephaneDucasse 4/4/2010 21:40'!
testParseFragment1
	"Query, then fragment."

	| uri uriString |
	uriString := 'scheme://host/path/to/resource?query#fragment'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self should: [uri isAbsolute].
	self shouldnt: [uri isOpaque].
	self should: [uri query = '?query'].
	self should: [uri fragment = 'fragment'].! !

!TestURI methodsFor: 'fragment' stamp: 'BEL 4/12/2003 18:25'!
testParseFragment10
	"Fragment only."

	| uri uriString |
	uriString := '#fragment'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self shouldnt: [uri isAbsolute].
	self shouldnt: [uri isOpaque].
	self should: [uri fragment = 'fragment'].! !

!TestURI methodsFor: 'fragment' stamp: 'BEL 3/31/2003 23:37'!
testParseFragment2
	"Fragment with no query."

	| uri uriString |
	uriString := 'scheme://host/path/to/resource#fragment'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self should: [uri isAbsolute].
	self shouldnt: [uri isOpaque].
	self should: [uri query isNil].
	self should: [uri fragment = 'fragment'].! !

!TestURI methodsFor: 'fragment' stamp: 'StephaneDucasse 4/4/2010 21:40'!
testParseFragment3
	"Relative path, query, then fragment."

	| uri uriString |
	uriString := '/path/to/resource?query#fragment'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self shouldnt: [uri isAbsolute].
	self shouldnt: [uri isOpaque].
	self should: [uri query = '?query'].
	self should: [uri fragment = 'fragment'].! !

!TestURI methodsFor: 'fragment' stamp: 'BEL 4/12/2003 18:26'!
testParseFragment4
	"Relative path, fragment with no query."

	| uri uriString |
	uriString := '/path/to/resource#fragment'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self shouldnt: [uri isAbsolute].
	self shouldnt: [uri isOpaque].
	self should: [uri query isNil].
	self should: [uri fragment = 'fragment'].! !

!TestURI methodsFor: 'fragment' stamp: 'BEL 3/31/2003 23:40'!
testParseFragment5
	"Even opaque parts can have fragments.  The empty fragment, in fact."

	| uri uriString |
	uriString := 'scheme:opaque#'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self should: [uri isAbsolute].
	self should: [uri isOpaque].
	self should: [uri fragment = ''].! !

!TestURI methodsFor: 'fragment' stamp: 'MarcusDenker 8/20/2011 13:54'!
testParseFragment6
	"No $# in a fragment."

	<expectedFailure>

	self should: [URI fromString: 'scheme:opaque#frag#ment']
		raise: IllegalURIException.


! !

!TestURI methodsFor: 'fragment' stamp: 'MarcusDenker 8/20/2011 13:55'!
testParseFragment7
	"No $| in a fragment."

	<expectedFailure>

	self should: [URI fromString: 'scheme:opaque#frag|ment']
		raise: IllegalURIException.


! !

!TestURI methodsFor: 'fragment' stamp: 'MarcusDenker 8/20/2011 13:55'!
testParseFragment8
	"No illegally escaped characters in a fragment."
	
	<expectedFailure>

	self should: [URI fromString: 'scheme:opaque#frag%ment']
		raise: Error


! !

!TestURI methodsFor: 'test path' stamp: 'MarcusDenker 8/20/2011 13:54'!
testPathForEmptyURI

	<expectedFailure>

	| uri uriString |
	uriString := ''.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self shouldnt: [uri isAbsolute].
	self should: [uri path isNil].
	self should: [uri query isNil].
	self should: [uri fragment isNil].! !

!TestURI methodsFor: 'test path' stamp: 'MarcusDenker 8/20/2011 13:54'!
testPathForSlash

	<expectedFailure>

	| uri uriString |
	uriString := '/'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri path size = 2)! !

!TestURI methodsFor: 'tests user info' stamp: 'MarcusDenker 8/20/2011 13:54'!
testPathWithBogusEscapedCharacters

	<expectedFailure>

	self should: [URI fromString: 'scheme:/path/to/e%rror']
		raise: Error! !

!TestURI methodsFor: 'test path' stamp: 'MarcusDenker 8/20/2011 13:52'!
testPathWithDotDot

	<expectedFailure>

	| uri uriString |
	uriString := '/../path/../to/resource'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self deny: (uri isAbsolute).
	self assert: (uri path size = 6).
		"may be we should have the path chunk"! !

!TestURI methodsFor: 'test path' stamp: 'MarcusDenker 8/20/2011 13:53'!
testPathWithFunkyCharacters
	"A relative path with exciting characters."

	<expectedFailure>

	| uri uriString |
	uriString := ';Super@c&a=l+i$,f-r_a.g!!i~l*i''s(t)i3c%20foobar/ative/path'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self shouldnt: [uri isAbsolute].
	self should: [uri path size = 3].! !

!TestURI methodsFor: 'test path' stamp: 'MarcusDenker 8/20/2011 13:54'!
testPathWithSimpleDot

	<expectedFailure>

	| uri uriString |
	uriString := '/path/./to/resource'.
	uri := URI fromString: uriString.
	self assert: ( uri asString = uriString).
	self assert: (uri path size = 5).! !

!TestURI methodsFor: 'test path' stamp: 'MarcusDenker 8/20/2011 13:54'!
testPathWithSimpleDotDot

	<expectedFailure>

	| uri uriString |
	uriString := '/path/../to/resource'.
	uri := URI fromString: uriString.
	self assert: ( uri asString = uriString).
	self assert: (uri path size = 5).! !

!TestURI methodsFor: 'test path' stamp: 'MarcusDenker 8/20/2011 13:53'!
testPathWithThreeParts

	<expectedFailure>

	| uri uriString |
	uriString := 'rel/ative/path'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self shouldnt: [uri isAbsolute].
	self should: [uri path size = 3].! !

!TestURI methodsFor: 'tests ports' stamp: 'StephaneDucasse 4/3/2010 17:56'!
testPortNumbersShouldNotHaveEscapingCharacters
	"No escaped characters can appear in a port; they turn it into a regName."

	| uri uriString |
	uriString := 'scheme://host:1%323/'.
	uri := URI fromString: uriString.
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri authority name =  'host:1')
	"may be this should be an error?"

! !

!TestURI methodsFor: 'tests query' stamp: 'MarcusDenker 8/20/2011 13:51'!
testQueryShouldNotContainEscape
	"Those characters cannot escape."

	<expectedFailure>

	self should: [URI fromString: 'scheme:/path/to/resource?que%ry']
		raise: Error
! !

!TestURI methodsFor: 'tests query' stamp: 'MarcusDenker 8/20/2011 13:53'!
testQueryShouldNotContainPipes
	"No questions about pipes, please."

	<expectedFailure>

	self should: [URI fromString: 'scheme:/path/to/resource?que|ry']
		raise: IllegalURIException
! !

!TestURI methodsFor: 'tests query' stamp: 'MarcusDenker 8/20/2011 13:53'!
testQueryWithALotCharacters
	
	<expectedFailure>
	
	| uri uriString |
	uriString := 'http:/path/to/resource?Pharo| is%20h-y3"p.er!!cool '.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri query = 'http:/path/to/resource?Pharo| is h-y3"p.er!!cool ').
! !

!TestURI methodsFor: 'tests query' stamp: 'MarcusDenker 8/20/2011 13:52'!
testQueryWithOnlyQueryPart
	"According to the BNF, there must be something besides questions, but according to the resolution examples, a relative URI containing only a query is just fine.  Since the latter is in common usage, we deviate from the BNF."
	
	<expectedFailure>

	| uri uriString |
	uriString := '?query'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self deny: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri query = 'query').! !

!TestURI methodsFor: 'tests authority' stamp: 'MarcusDenker 8/20/2011 13:52'!
testRelativeAuthority
	"self debug: #testRelativeAuthority"
	
	<expectedFailure>
	
	| uri relativeURIString |
	"A relative URI with authority. relative uri does not start with a scheme:."
	relativeURIString := '//www.pharo-project.org'. 
	uri := URI fromString: relativeURIString.
	self assert: (uri asString = relativeURIString).
	self deny: (uri isAbsolute).
	self assert: (uri isRelative). 
	self assert: (uri authority asString =  'www.pharo-project.org').
	self deny: (uri isOpaque).! !

!TestURI methodsFor: 'tests authority' stamp: 'MarcusDenker 8/20/2011 13:52'!
testRelativeEmptyAuthority
	"self debug: #testRelativeEmptyAuthority"
	"remember [scheme:][//authority][path][?query][#fragment]
		where authority can be [user-info@]host[:port]"
		
	<expectedFailure>	
		
	| uri uriString |
	uriString := '//'. "A relative URI with empty (but defined) authority."
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self deny: (uri isAbsolute).
	self deny: (uri authority isNil).
	self deny: (uri isOpaque).! !

!TestURI methodsFor: 'test path' stamp: 'MarcusDenker 8/20/2011 13:51'!
testRelativePathWithTrailingSlash
	
	<expectedFailure>
	
	| uri uriString |
	uriString := 'trailing/'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self deny: (uri isAbsolute).
	self assert: (uri path size = 2).! !

!TestURI methodsFor: 'tests query' stamp: 'MarcusDenker 8/20/2011 13:51'!
testRelativeQuery
	"Relative query."
	
	<expectedFailure>

	| uri uriString |
	uriString := '/path/to/resource?query'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self deny: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri query = 'query').! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal1
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../../../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/../g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal10
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := './g/.'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal11
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g/./h'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g/h'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal12
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g/../h'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/h'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal13
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g;x=1/./y'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g;x=1/y'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal14
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g;x=1/../y'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/y'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal15
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g?y/./x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g?y/./x'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 16:12'!
testResolveAbnormal16
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g?y/../x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g?y/../x'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal17
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g#s/./x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g#s/./x'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal18
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g#s/../x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g#s/../x'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal2
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../../../../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/../../g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal3
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '/./g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/./g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal4
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '/../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/../g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal5
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g.'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g.'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal6
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '.g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/.g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal7
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g..'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g..'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal8
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '..g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/..g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal9
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := './../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal1
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g:h'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'g:h'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal10
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g?y#s'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g?y#s'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal11
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := ';x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/;x'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal12
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g;x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g;x'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal13
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g;x?y#s'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g;x?y#s'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal14
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '.'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal15
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := './'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal16
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '..'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal17
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal18
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal19
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../..'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal2
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal20
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../../'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal21
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal3
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := './g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal4
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g/'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal5
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '/g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal6
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '//g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal7
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '?y'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/?y'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal8
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g?y'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g?y'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal9
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g#s'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g#s'].
! !

!TestURI methodsFor: 'parsing tests' stamp: 'StephaneDucasse 4/3/2010 18:18'!
testSchemeAbsolutePass2
	| uri |
	uri := URI fromString: 'mailto:somebody@somewhere.nowhere'.
	self assert: (uri scheme = 'mailto').
	self assert: (uri isAbsolute).
	self assert: (uri isOpaque).
	self deny: (uri isRelative)! !

!TestURI methodsFor: 'parsing tests' stamp: 'jannik.laval 5/2/2010 07:42'!
testSchemeAbsolutePass3
	| uri |
	uri := URI fromString: 'ftp://ftp@pharo.org'.
	self assert: (uri scheme = 'ftp').
	self assert: uri isAbsolute.
	self deny: (uri isOpaque).
	self deny: (uri isRelative).
	self assert: (uri userInfo = 'ftp').
	self assert: (uri host = 'pharo.org').
	self assert: (uri port isNil).
! !

!TestURI methodsFor: 'parsing tests' stamp: 'StephaneDucasse 4/3/2010 18:21'!
testSchemeAbsolutePass4
	| uri |
	uri := URI fromString: 'mailto:somebody@somewhere.nowhere#fragment'.
	self assert: (uri scheme = 'mailto').
	self assert: (uri isAbsolute).
	self assert: (uri isOpaque).
	self deny: (uri isRelative).
	self assert: (uri fragment = 'fragment').

! !

!TestURI methodsFor: 'parsing tests' stamp: 'VeronicaUquillas 6/11/2010 13:43'!
testSchemeAbsolutePass5
	| uri |
	uri := URI fromString: 'http://www.pharo-project.org#fragment'.
	self assert: (uri scheme = 'http').
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque).
	self deny: (uri isRelative).
	self assert: (uri fragment = 'fragment').
! !

!TestURI methodsFor: 'parsing tests' stamp: 'StephaneDucasse 4/3/2010 12:56'!
testSchemeCanContainPlusMinus
	"Digits and + and - and . are allowed."

	| uri uriString |
	uriString := 's-c+h.e1mE://host/'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri scheme = 's-c+h.e1mE').! !

!TestURI methodsFor: 'parsing tests' stamp: 'MarcusDenker 8/20/2011 13:55'!
testSchemeCannotStartWithDigit
	"A scheme cannot begin with a digit."

	<expectedFailure>

	self should: [URI fromString: '69cheme://host/']
		raise: IllegalURIException
! !

!TestURI methodsFor: 'expected failures' stamp: 'MarcusDenker 8/20/2011 13:56'!
testSchemeShouldNotContainAt
	"No @ in a scheme."
	
	<expectedFailure>

	self should: [URI fromString: 'sch@eme://host/']
		raise: IllegalURIException.
! !

!TestURI methodsFor: 'tests query' stamp: 'MarcusDenker 8/20/2011 13:56'!
testSimpleAbsoluteQuery
	"Absolute query."

	<expectedFailure>

	| uri uriString |
	uriString := 'scheme://host/path/to/resource?query'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri query = 'query').! !

!TestURI methodsFor: 'test path' stamp: 'MarcusDenker 8/20/2011 13:51'!
testSlashSlashSlashPath
	
	<expectedFailure>
	
	| uri uriString |
	uriString := '///'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self deny: (uri isAbsolute).
	self assert: (uri authority host asString = '').
	self assert: (uri path size = 2).! !

!TestURI methodsFor: 'tests user info' stamp: 'StephaneDucasse 4/2/2010 22:38'!
testUserInfo
	"self debug: #testUserInfo"
	
	| uri uriString |
	"[scheme:][//authority][path][?query][#fragment]
	where authority can be [user-info@]host[:port]"

	uriString := 'scheme://userinfo@host/'.
	uri :=  URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri authority userInfo = 'userinfo').! !

!TestURI methodsFor: 'tests user info' stamp: 'StephaneDucasse 4/2/2010 22:52'!
testUserInfoNoQuestionMark
	"No ? in the userInfo; it turns everything into a query."
	"self debug: #testUserInfoNoQuestionMark"
	
	| uri uriString |
	"[scheme:][//authority][path][?query][#fragment]
	where authority can be [user-info@]host[:port]"
	
	uriString := 'scheme://user?info@host/'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri authority host asString = 'user')! !

!TestURI methodsFor: 'tests user info' stamp: 'StephaneDucasse 4/2/2010 22:40'!
testUserInfoOnlyHost
	"self debug: #testUserInfoOnlyHost"
	
	| uri uriString |
	uriString := 'scheme://@host/'.
	"Empty but not undefined userinfo."
	
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri authority userInfo = '').! !

!TestURI methodsFor: 'expected failures' stamp: 'MarcusDenker 8/20/2011 13:55'!
testUserInfoWithIllegalCharacters
	"self debug: #testUserInfoWithIllegalCharacters"

	<expectedFailure>

	self should: [URI fromString: 'scheme://user%aeinfo@host/']
		raise: Error.
		
	"strange Escaped octets, that is, triplets consisting of the percent character ('%') followed by two hexadecimal digits ('0'-'9', 'A'-'F', and 'a'-'f')"! !

TestCase subclass: #UUIDPrimitivesTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-UUID'!

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'StephaneDucasse 11/5/2011 15:35'!
testComparison
	"self debug: #testComparison"
	|a b|
	a := UUID fromString: '0608b9dc-02e4-4dd0-9f8a-ea45160df641'.
	b := UUID fromString: 'e85ae7ba-3ca3-4bae-9f62-cc2ce51c525e'.
	self assert: a < b.
	self deny: a> b.
	
	a := UUID fromString: '0608b9dc-02e4-4dd0-9f8a-ea45160df641'.
	b := UUID fromString: '0608b9dc-02e4-4dd0-9f8a-ea45160df642'.
	self assert: a < b.
	
	a := UUID fromString: '0608b9dc-02e4-4dd0-9f8a-ea45160df641'.
	b := UUID fromString: '0608b9dc-02e4-4dd0-9f8a-ea45160df640'.
	self assert: a > b.
	! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:14'!
testCreation
	| uuid |
	uuid := UUID new.
	self should: [uuid size = 16].
	self shouldnt: [uuid isNilUUID].
	self should: [uuid asString size = 36].
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:27'!
testCreationEquality
	| uuid1 uuid2 |
	uuid1 := UUID new.
	uuid2 := UUID new.
	self should: [uuid1 = uuid1].
	self should: [uuid2 = uuid2].
	self shouldnt: [uuid1 = uuid2].
	self shouldnt: [uuid1 hash = uuid2 hash].
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:17'!
testCreationFromString
	| uuid string |
	string := UUID nilUUID asString.
	uuid := UUID fromString: string.
	self should: [uuid size = 16].
	self should: [uuid = UUID nilUUID].
	self should: [uuid isNilUUID].
	self should: [uuid asString size = 36].
	self should: [uuid asArray asSet size = 1].
	self should: [(uuid asArray asSet asArray at: 1) = 0].
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'StephaneDucasse 8/21/2010 20:54'!
testCreationFromString36NotNil
	| uuid uuid36 |
	uuid := UUID fromString: 'fedcba98-7654-3210-0123-456789abcdef'.
	uuid36 := UUID fromString36: 'e738i8a5the1f87mrh14o6vi6'.
	self should: [uuid = uuid36]! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'StephaneDucasse 8/21/2010 20:58'!
testCreationFromString36With0
	| uuid |
	uuid := UUID fromString36: '0'.
	self assert: (uuid isNilUUID).
	
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'StephaneDucasse 8/21/2010 20:59'!
testCreationFromString36WithNillUUID
	
	self shouldnt: [UUID fromString36: (UUID nilUUID asString36)] 
    		raise: Error.! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:18'!
testCreationFromStringNotNil
	| uuid string |
	string := UUID new asString.
	uuid := UUID fromString: string.
	self should: [uuid size = 16].
	self should: [uuid asString size = 36].

! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:16'!
testCreationNil
	| uuid |
	uuid := UUID nilUUID.
	self should: [uuid size = 16].
	self should: [uuid isNilUUID].
	self should: [uuid asString size = 36].
	self should: [uuid asArray asSet size = 1].
	self should: [(uuid asArray asSet asArray at: 1) = 0].
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'nice 1/5/2010 15:59'!
testCreationNodeBased
	

	(UUID new asString last: 12) = (UUID new asString last: 12) ifFalse: [^self].
	1000 timesRepeat:
		[ | uuid |uuid := UUID new.
		self should: [((uuid at: 7) bitAnd: 16rF0) = 16r10].
		self should: [((uuid at: 9) bitAnd: 16rC0) = 16r80]]
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'nice 1/5/2010 15:59'!
testDuplicationsKinda
	| check size |

	size := 5000.
	check := Set new: size.
	size timesRepeat: 
		[ | uuid |uuid := UUID new.
		self shouldnt: [check includes: uuid].
		check add: uuid].
		! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'nice 1/5/2010 15:59'!
testOrder
	
	100 timesRepeat:
		[ | uuid1 uuid2 |uuid1 := UUID new.
		uuid2 := UUID new.
		(uuid1 asString last: 12) = (uuid2 asString last: 12) ifTrue:
			[self should: [uuid1 < uuid2].
			self should: [uuid2 > uuid1].
			self shouldnt: [uuid1 = uuid2]]]
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'StephaneDucasse 7/22/2011 18:09'!
testUniqueness 
	"Test uniqueness for a given number of generated values"
	
	|maxTestValue|
	maxTestValue := 1000.
	self assert: ((1 to: maxTestValue) collect: [ :i | UUID new asString ]) asSet size = maxTestValue! !

TestCase subclass: #UUIDTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-UUID'!

!UUIDTest methodsFor: 'testing' stamp: 'EstebanLorenzano 11/18/2011 13:58'!
testComparison
	|a b|
	
	a := UUID fromString: '0608b9dc-02e4-4dd0-9f8a-ea45160df641'.
	b := UUID fromString: 'e85ae7ba-3ca3-4bae-9f62-cc2ce51c525e'.
	
	self assert: a = a copy.
	self assert: b = b copy.
	self assert: a < b.
	self assert: b > a.
	
	self deny: (a > b) = (b > a)
	
	! !

Stream subclass: #MockSocketStream
	instanceVariableNames: 'atEnd inStream outStream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Kernel'!

!MockSocketStream class methodsFor: 'instance creation' stamp: 'fbs 3/22/2004 12:46'!
on: socket
	^self basicNew initialize! !

!MockSocketStream methodsFor: 'testing' stamp: 'fbs 3/22/2004 13:08'!
atEnd
	^self inStream atEnd.! !

!MockSocketStream methodsFor: 'accessing' stamp: 'fbs 3/22/2004 12:51'!
atEnd: aBoolean
	atEnd := aBoolean.! !

!MockSocketStream methodsFor: 'accessing' stamp: 'fbs 3/22/2004 13:29'!
inStream
	^inStream! !

!MockSocketStream methodsFor: 'initialization' stamp: 'alain.plantec 5/28/2009 10:08'!
initialize
	super initialize.
	self resetInStream.
	self resetOutStream.! !

!MockSocketStream methodsFor: 'stream in' stamp: 'fbs 3/22/2004 13:10'!
nextLine
	^self nextLineCrLf! !

!MockSocketStream methodsFor: 'stream in' stamp: 'fbs 3/22/2004 13:09'!
nextLineCrLf
	^(self upToAll: String crlf).! !

!MockSocketStream methodsFor: 'accessing' stamp: 'fbs 3/22/2004 13:08'!
outStream
	^outStream! !

!MockSocketStream methodsFor: 'stream in' stamp: 'PeterHugossonMiller 9/3/2009 10:05'!
resetInStream
	inStream := String new writeStream.! !

!MockSocketStream methodsFor: 'stream out' stamp: 'PeterHugossonMiller 9/3/2009 10:05'!
resetOutStream
	outStream := String new writeStream.! !

!MockSocketStream methodsFor: 'stream out' stamp: 'fbs 3/22/2004 13:07'!
sendCommand: aString
	self outStream
		nextPutAll: aString;
		nextPutAll: String crlf.! !

!MockSocketStream methodsFor: 'stream in' stamp: 'fbs 3/22/2004 13:09'!
upToAll: delims
	^self inStream upToAll: delims.! !
